@@ -27,11 +27,9 @@ class ConfigMixin(object):
 		client={'id', 'secret'},
 		auth={'code', 'refresh_token', 'access_expires', 'access_token'})
 
-
 	def __init__(self, **kwz):
 		raise NotImplementedError('Init should be overidden with something configurable')
 
-
 	@classmethod
 	def from_conf(cls, path=None, **overrides):
 		'''Initialize instance from YAML configuration file,
@@ -56,11 +54,11 @@ class ConfigMixin(object):
 					v = conf.get(ns, dict()).get(k)
 				except AttributeError:
 					if not cls.conf_raise_structure_errors: raise
-					raise KeyError('Unable to get value for configuration parameter'
-								' "{k}" in section "{ns}", check configuration file (path: {path}) syntax' #!as3
-								' near the aforementioned section/value.'.format(ns=ns, k=k, path=path)) #!as3
-				if v is not None:
-					conf_cls['{}_{}'.format(ns, k)] = conf[ns][k]
+					raise KeyError((
+						'Unable to get value for configuration parameter'
+							' "{k}" in section "{ns}", check configuration file (path: {path}) syntax'
+							' near the aforementioned section/value.' ).format(ns=ns, k=k, path=path))
+				if v is not None: conf_cls['{}_{}'.format(ns, k)] = conf[ns][k]
 		conf_cls.update(overrides)
 
 		self = cls(**conf_cls)
@@ -101,8 +99,7 @@ class ConfigMixin(object):
 					# Should probably be fixed by someone who uses/knows about windows
 					portalocker.lock(src, portalocker.LOCK_EX)
 					src.seek(0)
-					if src.read() != conf_raw:
-						retry = True
+					if src.read() != conf_raw: retry = True
 					else:
 						src.seek(0)
 						src.truncate()
@@ -117,8 +114,7 @@ class ConfigMixin(object):
 						try:
 							portalocker.lock(src, portalocker.LOCK_EX)
 							src.seek(0)
-							if src.read() != conf_raw:
-								retry = True
+							if src.read() != conf_raw: retry = True
 							else:
 								portalocker.lock(tmp, portalocker.LOCK_EX)
 								tmp.write(conf_new)
@@ -130,12 +126,11 @@ class ConfigMixin(object):
 								src.truncate()
 								src.write(conf_new)
 						finally:
-							try:
-								os.unlink(tmp.name)
-							except OSError:
-								pass
+							try: os.unlink(tmp.name)
+							except OSError: pass
 
 		if retry:
-			log.debug( 'Configuration file (%r) was changed'
-						' during merge, restarting merge', self.conf_save)
+			log.debug(
+				'Configuration file (%r) was changed'
+					' during merge, restarting merge', self.conf_save )
 			return self.sync()
